
From: Andrew Morton <akpm@osdl.org>

Readability.  Mainly make it fit into an 80-col xterm.

Cc: Seetharami Seelam <seelam@cs.utep.edu>
Cc: Nick Piggin <npiggin@suse.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/block/as-iosched.c |   46 ++++++++++++++++++++++++++-------------------
 1 files changed, 27 insertions(+), 19 deletions(-)

diff -puN drivers/block/as-iosched.c~as-tidy drivers/block/as-iosched.c
--- devel/drivers/block/as-iosched.c~as-tidy	2005-09-12 01:52:16.000000000 -0700
+++ devel-akpm/drivers/block/as-iosched.c	2005-09-12 01:52:16.000000000 -0700
@@ -640,7 +640,8 @@ static void as_antic_timeout(unsigned lo
 	spin_unlock_irqrestore(q->queue_lock, flags);
 }
 
-static void as_update_thinktime(struct as_data *ad, struct as_io_context *aic, unsigned long ttime)
+static void as_update_thinktime(struct as_data *ad, struct as_io_context *aic,
+				unsigned long ttime)
 {
 	/* fixed point: 1.0 == 1<<8 */
 	if (aic->ttime_samples == 0) {
@@ -654,7 +655,8 @@ static void as_update_thinktime(struct a
 	aic->ttime_mean = (aic->ttime_total + 128) / aic->ttime_samples;
 }
 
-static void as_update_seekdist(struct as_data *ad, struct as_io_context *aic, sector_t sdist)
+static void as_update_seekdist(struct as_data *ad, struct as_io_context *aic,
+				sector_t sdist)
 {
 	u64 total;
 
@@ -684,7 +686,8 @@ static void as_update_seekdist(struct as
  * updates @aic->ttime_mean based on that. It is called when a new
  * request is queued.
  */
-static void as_update_iohist(struct as_data *ad, struct as_io_context *aic, struct request *rq)
+static void as_update_iohist(struct as_data *ad, struct as_io_context *aic,
+				struct request *rq)
 {
 	struct as_rq *arq = RQ_DATA(rq);
 	int data_dir = arq->is_sync;
@@ -725,7 +728,8 @@ static void as_update_iohist(struct as_d
  * as_close_req decides if one request is considered "close" to the
  * previous one issued.
  */
-static int as_close_req(struct as_data *ad, struct as_io_context *aic, struct as_rq *arq)
+static int as_close_req(struct as_data *ad, struct as_io_context *aic,
+				struct as_rq *arq)
 {
 	unsigned long delay;	/* milliseconds */
 	sector_t last = ad->last_sector[ad->batch_data_dir];
@@ -893,7 +897,6 @@ static int as_can_anticipate(struct as_d
 	 * Status is either ANTIC_OFF so start waiting,
 	 * ANTIC_WAIT_REQ so continue waiting for request to finish
 	 * or ANTIC_WAIT_NEXT so continue waiting for an acceptable request.
-	 *
 	 */
 
 	return 1;
@@ -1389,7 +1392,8 @@ static struct request *as_next_request(r
  * Add arq to a list behind alias
  */
 static inline void
-as_add_aliased_request(struct as_data *ad, struct as_rq *arq, struct as_rq *alias)
+as_add_aliased_request(struct as_data *ad, struct as_rq *arq,
+				struct as_rq *alias)
 {
 	struct request  *req = arq->request;
 	struct list_head *insert = alias->request->queuelist.prev;
@@ -1484,11 +1488,11 @@ static void as_deactivate_request(reques
 		if (arq->state == AS_RQ_REMOVED) {
 			arq->state = AS_RQ_DISPATCHED;
 			if (arq->io_context && arq->io_context->aic)
-				atomic_inc(&arq->io_context->aic->nr_dispatched);
+			    atomic_inc(&arq->io_context->aic->nr_dispatched);
 		}
 	} else
 		WARN_ON(blk_fs_request(rq)
-			&& (!(rq->flags & (REQ_HARDBARRIER|REQ_SOFTBARRIER))) );
+			&& (!(rq->flags & (REQ_HARDBARRIER|REQ_SOFTBARRIER))));
 
 	/* Stop anticipating - let this request get through */
 	as_antic_stop(ad);
@@ -1546,7 +1550,8 @@ as_insert_request(request_queue_t *q, st
 				as_move_to_dispatch(ad, ad->next_arq[REQ_SYNC]);
 
 			while (ad->next_arq[REQ_ASYNC])
-				as_move_to_dispatch(ad, ad->next_arq[REQ_ASYNC]);
+				as_move_to_dispatch(ad,
+						ad->next_arq[REQ_ASYNC]);
 
 			list_add_tail(&rq->queuelist, ad->dispatch);
 			as_account_queued_request(ad, rq);
@@ -1585,8 +1590,8 @@ static int as_queue_empty(request_queue_
 	return 1;
 }
 
-static struct request *
-as_former_request(request_queue_t *q, struct request *rq)
+static struct request *as_former_request(request_queue_t *q,
+					struct request *rq)
 {
 	struct as_rq *arq = RQ_DATA(rq);
 	struct rb_node *rbprev = rb_prev(&arq->rb_node);
@@ -1598,8 +1603,8 @@ as_former_request(request_queue_t *q, st
 	return ret;
 }
 
-static struct request *
-as_latter_request(request_queue_t *q, struct request *rq)
+static struct request *as_latter_request(request_queue_t *q,
+					struct request *rq)
 {
 	struct as_rq *arq = RQ_DATA(rq);
 	struct rb_node *rbnext = rb_next(&arq->rb_node);
@@ -1710,9 +1715,8 @@ static void as_merged_request(request_qu
 		q->last_merge = req;
 }
 
-static void
-as_merged_requests(request_queue_t *q, struct request *req,
-			 struct request *next)
+static void as_merged_requests(request_queue_t *q, struct request *req,
+			 	struct request *next)
 {
 	struct as_data *ad = q->elevator->elevator_data;
 	struct as_rq *arq = RQ_DATA(req);
@@ -1963,10 +1967,14 @@ static ssize_t as_est_show(struct as_dat
 {
 	int pos = 0;
 
-	pos += sprintf(page+pos, "%lu %% exit probability\n", 100*ad->exit_prob/256);
-	pos += sprintf(page+pos, "%lu %% probability of exiting without a cooperating process submitting IO\n", 100*ad->exit_no_coop/256);
+	pos += sprintf(page+pos, "%lu %% exit probability\n",
+				100*ad->exit_prob/256);
+	pos += sprintf(page+pos, "%lu %% probability of exiting without a "
+				"cooperating process submitting IO\n",
+				100*ad->exit_no_coop/256);
 	pos += sprintf(page+pos, "%lu ms new thinktime\n", ad->new_ttime_mean);
-	pos += sprintf(page+pos, "%llu sectors new seek distance\n", (unsigned long long)ad->new_seek_mean);
+	pos += sprintf(page+pos, "%llu sectors new seek distance\n",
+				(unsigned long long)ad->new_seek_mean);
 
 	return pos;
 }
_
